#
# Copyright (c) 2023, HILSTER - https://hilster.io
# All rights reserved.
#

from oser.fuzzing import (
    RandomIntegerFuzzingValue,
    RandomFloatFuzzingValue,
    RandomBitsFuzzingValue,
    RandomStringFuzzingValue,
    RandomBytesFuzzingValue,
)
from .__version__ import __version_info__, __version__
from .array_type import Array
from .bitmap import BitMap
from .constant import Constant
from .core import (
    ByteType,
    BitType,
    ByteStruct,
    BitStruct,
    EncodeException,
    DecodeException,
    ChecksumMismatchException,
    RegularExpressionMismatchException,
    OserNode,
)
from .crc import CRCL8, CRCB8, CRCL16, CRCB16, CRCL32, CRCB32, CRCL64, CRCB64
from .data import Data
from .enum import Enum
from .if_ import If
from .if_else import IfElse
from .json_adapter import JSONAdapter
from .lazy_initialization import Lazy
from .modbus import (
    UInt3412,
    UInt2143,
    UInt21436587,
    UInt78563412,
    SInt3412,
    SInt2143,
    SInt21436587,
    SInt78563412,
    Float3412,
    Float2143,
    Double78563412,
    Double21436587,
)
from .nothing import Nothing
from .null import Null
from .padding import Padding
from .padding_flag import PaddingFlag
from .protocol_buffers_adapter import ProtocolBuffersAdapter
from .regular_expression_match import RegularExpressionMatch
from .repeat_until import RepeatUntil
from .string_ import String
from .switch import Switch
from .typedef import (
    BDouble,
    BFloat,
    BitField,
    Flag,
    LDouble,
    LFloat,
    Nibble,
    SBInt16,
    SBInt32,
    SBInt64,
    SBInt8,
    SLInt16,
    SLInt32,
    SLInt64,
    SLInt8,
    UBInt16,
    UBInt32,
    UBInt64,
    UBInt8,
    ULInt16,
    ULInt32,
    ULInt64,
    ULInt8,
)
from .util import to_hex
from .value import Value
from .varint import UBVarInt, ULVarInt, SBVarInt, SLVarInt

__all__ = [
    "__version_info__",
    "__version__",
    "OserNode",
    "ByteType",
    "BitType",
    "ByteStruct",
    "BitStruct",
    "EncodeException",
    "DecodeException",
    "ChecksumMismatchException",
    "RegularExpressionMismatchException",
    "UBVarInt",
    "ULVarInt",
    "SBVarInt",
    "SLVarInt",
    "BDouble",
    "BFloat",
    "BitField",
    "Flag",
    "LDouble",
    "LFloat",
    "Nibble",
    "SBInt16",
    "SBInt32",
    "SBInt64",
    "SBInt8",
    "SLInt16",
    "SLInt32",
    "SLInt64",
    "SLInt8",
    "UBInt16",
    "UBInt32",
    "UBInt64",
    "UBInt8",
    "ULInt16",
    "ULInt32",
    "ULInt64",
    "ULInt8",
    "Constant",
    "Array",
    "BitMap",
    "Enum",
    "If",
    "IfElse",
    "RandomIntegerFuzzingValue",
    "RandomFloatFuzzingValue",
    "RandomBitsFuzzingValue",
    "RandomStringFuzzingValue",
    "RandomBytesFuzzingValue",
    "Null",
    "PaddingFlag",
    "Padding",
    "Nothing",
    "String",
    "Data",
    "Switch",
    "Value",
    "Lazy",
    "UInt3412",
    "UInt2143",
    "UInt21436587",
    "UInt78563412",
    "SInt3412",
    "SInt2143",
    "SInt21436587",
    "SInt78563412",
    "Float3412",
    "Float2143",
    "Double78563412",
    "Double21436587",
    "JSONAdapter",
    "ProtocolBuffersAdapter",
    "RegularExpressionMatch",
    "RepeatUntil",
    "CRCL8",
    "CRCB8",
    "CRCL16",
    "CRCB16",
    "CRCL32",
    "CRCB32",
    "CRCL64",
    "CRCB64",
    "to_hex",
]
