#
# Copyright (c) 2023, HILSTER - https://hilster.io
# All rights reserved.
#

from typing import Type, Any

from oser.core import Lazy as _Lazy
from oser.types import OserElementType


class Lazy(_Lazy):
    """
    ``Lazy`` can be used to realize lazy-initialization automatically.

    `cls` is instantiated on first access but not in :func:`__init__`.
    So if no access is done it will never be instantiated and will not occupy any memory and cpu time.
    """

    def __init__(self, cls: Type[OserElementType], *args: OserElementType, **kwargs: Any) -> None:
        """
        Args:
            cls: the class to be instantiated.
            *args: a tuple for positional arguments for ``cls``.
            **kwargs: a dict for named arguments for ``cls``.
        """
        super(Lazy, self).__init__(cls, *args, **kwargs)
